[Libreoffice-commits] .: basic/source cosv/inc desktop/source framework/inc framework/qa framework/source guw/guw.cc l10ntools/source libxml2/libxml2-long-path.patch linguistic/source odk/examples officecfg/registry qadevOOo/runner rsc/inc setup_native/scripts solenv/bin solenv/inc stoc/source svtools/source tools/source udkapi/com unotools/inc unotools/source wizards/com

Jesús Corrius jcorrius at kemper.freedesktop.org
Wed Feb 1 05:46:25 PST 2012


 basic/source/uno/namecont.cxx                                    |    2 -
 cosv/inc/cosv/persist.hxx                                        |    2 -
 desktop/source/deployment/registry/package/dp_package.cxx        |    2 -
 framework/inc/classes/filtercachedata.hxx                        |    6 +--
 framework/inc/classes/protocolhandlercache.hxx                   |    2 -
 framework/inc/services/pathsettings.hxx                          |    2 -
 framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java |    2 -
 framework/source/accelerators/storageholder.cxx                  |    2 -
 framework/source/services/desktop.cxx                            |    2 -
 framework/source/services/frame.cxx                              |    4 +-
 framework/source/services/pathsettings.cxx                       |   16 +++++-----
 guw/guw.cc                                                       |    2 -
 l10ntools/source/filter/utils/FileHelper.java                    |    4 +-
 libxml2/libxml2-long-path.patch                                  |    2 -
 linguistic/source/misc2.cxx                                      |    6 +--
 odk/examples/DevelopersGuide/Forms/URLHelper.java                |    2 -
 officecfg/registry/schema/org/openoffice/Office/Paths.xcs        |    4 +-
 qadevOOo/runner/helper/URLHelper.java                            |    4 +-
 rsc/inc/rscrsc.hxx                                               |    2 -
 setup_native/scripts/admin.pl                                    |    4 +-
 solenv/bin/make_installer.pl                                     |    4 +-
 solenv/bin/modules/installer/archivefiles.pm                     |    2 -
 solenv/bin/modules/installer/control.pm                          |    2 -
 solenv/bin/modules/installer/converter.pm                        |    2 -
 solenv/bin/modules/installer/downloadsigner.pm                   |   16 +++++-----
 solenv/bin/modules/installer/environment.pm                      |    2 -
 solenv/bin/modules/installer/epmfile.pm                          |    2 -
 solenv/bin/modules/installer/packagelist.pm                      |    4 +-
 solenv/bin/modules/installer/parameter.pm                        |    2 -
 solenv/bin/modules/installer/scriptitems.pm                      |    6 +--
 solenv/bin/modules/installer/windows/admin.pm                    |    2 -
 solenv/bin/modules/installer/windows/directory.pm                |    2 -
 solenv/bin/modules/installer/windows/msp.pm                      |    2 -
 solenv/bin/modules/installer/windows/update.pm                   |    2 -
 solenv/bin/modules/installer/ziplist.pm                          |    6 +--
 solenv/bin/modules/par2script/parameter.pm                       |    4 +-
 solenv/bin/modules/par2script/work.pm                            |    6 +--
 solenv/bin/modules/pre2par/parameter.pm                          |    2 -
 solenv/bin/packimages.pl                                         |    2 -
 solenv/inc/settings.mk                                           |    2 -
 stoc/source/security/permissions.cxx                             |    4 +-
 svtools/source/control/inettbc.cxx                               |    4 +-
 tools/source/fsys/filecopy.cxx                                   |    2 -
 udkapi/com/sun/star/beans/XHierarchicalPropertySet.idl           |    2 -
 unotools/inc/unotools/configitem.hxx                             |    2 -
 unotools/inc/unotools/configpathes.hxx                           |    6 +--
 unotools/inc/unotools/pathoptions.hxx                            |    4 +-
 unotools/source/config/configitem.cxx                            |    4 +-
 unotools/source/config/configpathes.cxx                          |    4 +-
 unotools/source/config/defaultoptions.cxx                        |    4 +-
 unotools/source/config/moduleoptions.cxx                         |    4 +-
 unotools/source/config/pathoptions.cxx                           |    4 +-
 wizards/com/sun/star/wizards/web/WWD_Startup.java                |    2 -
 wizards/com/sun/star/wizards/web/WWD_Startup.py                  |    2 -
 54 files changed, 96 insertions(+), 96 deletions(-)

New commits:
commit 7be0cc289d9745e0842c4fa6c0a6ac3450f3801b
Author: Jesús Corrius <jesus at softcatala.org>
Date:   Wed Feb 1 14:42:58 2012 +0100

    A few safe replacements of pathes->paths

diff --git a/basic/source/uno/namecont.cxx b/basic/source/uno/namecont.cxx
index f65a6eb..db0bf66 100644
--- a/basic/source/uno/namecont.cxx
+++ b/basic/source/uno/namecont.cxx
@@ -661,7 +661,7 @@ sal_Bool SfxLibraryContainer::init_Impl(
     }
     else
     {
-        // Default pathes
+        // Default paths
         maLibraryPath = SvtPathOptions().GetBasicPath();
     }
 
diff --git a/cosv/inc/cosv/persist.hxx b/cosv/inc/cosv/persist.hxx
index 9a3905d..dd20c3e 100644
--- a/cosv/inc/cosv/persist.hxx
+++ b/cosv/inc/cosv/persist.hxx
@@ -65,7 +65,7 @@ class Persistent
     virtual             ~Persistent() {}
 
     const Path &        MyPath() const;
-    /// @return all pathes without completing delimiter, even directories.
+    /// @return all paths without completing delimiter, even directories.
     const char *        StrPath() const;
     bool                Exists() const;
 
diff --git a/desktop/source/deployment/registry/package/dp_package.cxx b/desktop/source/deployment/registry/package/dp_package.cxx
index 3fa6ba1..dac1ff6 100644
--- a/desktop/source/deployment/registry/package/dp_package.cxx
+++ b/desktop/source/deployment/registry/package/dp_package.cxx
@@ -1565,7 +1565,7 @@ void BackendImpl::PackageImpl::scanLegacyBundle(
 {
     ::ucbhelper::Content ucbContent( url, xCmdEnv );
 
-    // check for platform pathes:
+    // check for platform paths:
     const OUString title( ucbContent.getPropertyValue(
                               StrTitle::get() ).get<OUString>() );
     if (title.endsWithIgnoreAsciiCaseAsciiL(
diff --git a/framework/inc/classes/filtercachedata.hxx b/framework/inc/classes/filtercachedata.hxx
index ba77457..db320eb 100644
--- a/framework/inc/classes/filtercachedata.hxx
+++ b/framework/inc/classes/filtercachedata.hxx
@@ -78,9 +78,9 @@ namespace framework{
 
 #define PACKAGENAME_TYPEDETECTION_STANDARD          DECLARE_ASCII("Office.TypeDetection"                            )   /// Names of our configuration files.
 #define PACKAGENAME_TYPEDETECTION_ADDITIONAL        DECLARE_ASCII("Office.TypeDetectionAdditional"                  )
-#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration pathes
-#define PROPERTY_SEPERATOR                          sal_Unicode(',')                                                    /// seperator for own formated property strings of types and filters
-#define LIST_SEPERATOR                              sal_Unicode(';')                                                    /// seperator for own formated lists as part of our own formated type- or filter-string
+#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// separator for configuration paths
+#define PROPERTY_SEPERATOR                          sal_Unicode(',')                                                    /// separator for own formated property strings of types and filters
+#define LIST_SEPERATOR                              sal_Unicode(';')                                                    /// separator for own formated lists as part of our own formated type- or filter-string
 #define LOCALE_FALLBACK                             DECLARE_ASCII("en-US"                                           )   /// fallback, if configuration can't give us current set locale ...
 #define DEFAULT_FILTERCACHE_VERSION                 6                                                                   /// these implmentation of FilterCache support different version of TypeDetection.xml! This define the current set default one.
 
diff --git a/framework/inc/classes/protocolhandlercache.hxx b/framework/inc/classes/protocolhandlercache.hxx
index 79f4cdc..8fe3dfc 100644
--- a/framework/inc/classes/protocolhandlercache.hxx
+++ b/framework/inc/classes/protocolhandlercache.hxx
@@ -62,7 +62,7 @@ namespace framework{
 
 #define PACKAGENAME_PROTOCOLHANDLER                 DECLARE_ASCII("Office.ProtocolHandler"                          )   /// name of our configuration package
 
-#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// seperator for configuration pathes
+#define CFG_PATH_SEPERATOR                          DECLARE_ASCII("/"                                               )   /// separator for configuration paths
 #define CFG_ENCODING_OPEN                           DECLARE_ASCII("[\'"                                             )   /// used to start encoding of set names
 #define CFG_ENCODING_CLOSE                          DECLARE_ASCII("\']"                                             )   /// used to finish encoding of set names
 
diff --git a/framework/inc/services/pathsettings.hxx b/framework/inc/services/pathsettings.hxx
index 8e7d1de..e587cc5 100644
--- a/framework/inc/services/pathsettings.hxx
+++ b/framework/inc/services/pathsettings.hxx
@@ -118,7 +118,7 @@ class PathSettings : public  css::lang::XTypeProvider             ,
             /// this special path is used to generate feature depending content there
             ::rtl::OUString sWritePath;
 
-            /// indicates real single pathes, which uses WritePath property only
+            /// indicates real single paths, which uses WritePath property only
             sal_Bool bIsSinglePath;
 
             /// simple handling of finalized/mandatory states ... => we know one state READONLY only .-)
diff --git a/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java b/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
index 1c67271..425b91e 100755
--- a/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
+++ b/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
@@ -75,7 +75,7 @@ import static org.junit.Assert.*;
             The parameters for this have to be "ftp_access" and "http_access".
             If they are not given, tests for ftp and http will fail.
 
-    @todo   We need a further test for accessing UNC pathes on windows!
+    @todo   We need a further test for accessing UNC paths on windows!
  */
 public class CheckXComponentLoader
 {
diff --git a/framework/source/accelerators/storageholder.cxx b/framework/source/accelerators/storageholder.cxx
index d60e18d..285b771 100644
--- a/framework/source/accelerators/storageholder.cxx
+++ b/framework/source/accelerators/storageholder.cxx
@@ -295,7 +295,7 @@ void StorageHolder::closePath(const ::rtl::OUString& rPath)
     ::rtl::OUString sNormedPath = StorageHolder::impl_st_normPath(rPath);
     OUStringList    lFolders    = StorageHolder::impl_st_parsePath(sNormedPath);
 
-    /* convert list of pathes in the following way:
+    /* convert list of paths in the following way:
         [0] = "path_1" => "path_1
         [1] = "path_2" => "path_1/path_2"
         [2] = "path_3" => "path_1/path_2/path_3"
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index c6d414c..eccd010 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -555,7 +555,7 @@ css::uno::Reference< css::lang::XComponent > SAL_CALL Desktop::getCurrentCompone
 /*-************************************************************************************************************//**
     @interface  XDesktop
     @short      return the current active frame in hierarchy
-    @descr      There can be more then one different active pathes in our frame hierarchy. But only one of them
+    @descr      There can be more then one different active paths in our frame hierarchy. But only one of them
                 could be the most active frame (normal he has the focus).
                 Don't mix it with getActiveFrame()! That will return our current active frame, which must be
                 a direct child of us and should be a part(!) of an active path.
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index cd60a6c..7db9117 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -1051,7 +1051,7 @@ sal_Bool SAL_CALL Frame::isTop() throw( css::uno::RuntimeException )
 
 /*-****************************************************************************************************//**
     @short      activate frame in hierarchy
-    @descr      This feature is used to mark active pathes in our frame hierarchy.
+    @descr      This feature is used to mark active paths in our frame hierarchy.
                 You can be a listener for this event to react for it ... change some internal states or something else.
 
     @seealso    method deactivate()
@@ -1151,7 +1151,7 @@ void SAL_CALL Frame::activate() throw( css::uno::RuntimeException )
 
 /*-****************************************************************************************************//**
     @short      deactivate frame in hierarchy
-    @descr      This feature is used to deactive pathes in our frame hierarchy.
+    @descr      This feature is used to deactive paths in our frame hierarchy.
                 You can be a listener for this event to react for it ... change some internal states or something else.
 
     @seealso    method activate()
diff --git a/guw/guw.cc b/guw/guw.cc
index 431866c..b1186db 100644
--- a/guw/guw.cc
+++ b/guw/guw.cc
@@ -473,7 +473,7 @@ void myCygpath(string &path, int shortname /* =1 */ )
 
   // Only use cygwin_conv_to_win32_path() on absolute paths as it errors
   // out if its path doen't exist. Unfortunatelt there are a lot of not
-  // existing relative pathes used as parameters during an OOo build.
+  // existing relative paths used as parameters during an OOo build.
   if( path.find("/", 0) == 0) {
     err = cygwin_conv_to_win32_path( path.c_str(), convpath );
   }
diff --git a/l10ntools/source/filter/utils/FileHelper.java b/l10ntools/source/filter/utils/FileHelper.java
index e7e5766..7c414eb 100644
--- a/l10ntools/source/filter/utils/FileHelper.java
+++ b/l10ntools/source/filter/utils/FileHelper.java
@@ -38,7 +38,7 @@ import java.util.*;
 
 /**
  * It collects some static helper functons to handle file system specific problems.
- * Sometimes it's neccessary to convert URL from/to system pathes;
+ * Sometimes it's neccessary to convert URL from/to system paths;
  * or from string notation to structural versions (e.g. com.sun.star.util.URL).
  * And sometimes java had another notation then the office it has.
  * Further it provides functionality to work easiear with the java.io.File class of java.
@@ -51,7 +51,7 @@ public class FileHelper
 
     /**
      * Because the office need URLs for loading/saving documents
-     * we must convert used system pathes.
+     * we must convert used system paths.
      * And java use another notation for file URLs ... correct it.
      *
      * @param aSystemPath
diff --git a/libxml2/libxml2-long-path.patch b/libxml2/libxml2-long-path.patch
index bd888d9..c27dbe1 100644
--- a/libxml2/libxml2-long-path.patch
+++ b/libxml2/libxml2-long-path.patch
@@ -8,7 +8,7 @@
 +#if defined(_WIN32) 	
 +	//We must not change the backslashes to slashes if the the path starts with
 +	// \\?\
-+	//Those pathes can be up to 32k characters long.
++	//Those paths can be up to 32k characters long.
 +	len = xmlStrlen(path);
 +	if ((len > 3) && (path[0] == '\\') && (path[1] == '\\') && (path[2] == '?') && (path[3] == '\\') )
 +		return xmlStrdup((const xmlChar *) path);
diff --git a/linguistic/source/misc2.cxx b/linguistic/source/misc2.cxx
index 8ca3cc0..4063365 100644
--- a/linguistic/source/misc2.cxx
+++ b/linguistic/source/misc2.cxx
@@ -104,10 +104,10 @@ static uno::Sequence< rtl::OUString > GetMultiPaths_Impl(
     }
     if (bSuccess)
     {
-        // build resulting sequence by adding the pathes in the following order:
+        // build resulting sequence by adding the paths in the following order:
         // 1. writable path
-        // 2. all user pathes
-        // 3. all internal pathes
+        // 2. all user paths
+        // 3. all internal paths
         sal_Int32 nMaxEntries = aInternalPaths.getLength() + aUserPaths.getLength();
         if (!aWritablePath.isEmpty())
             ++nMaxEntries;
diff --git a/odk/examples/DevelopersGuide/Forms/URLHelper.java b/odk/examples/DevelopersGuide/Forms/URLHelper.java
index 947b6c3..343453a 100644
--- a/odk/examples/DevelopersGuide/Forms/URLHelper.java
+++ b/odk/examples/DevelopersGuide/Forms/URLHelper.java
@@ -32,7 +32,7 @@ public class URLHelper
 {
     /**
      * Because the office need URLs for loading/saving documents
-     * we must convert used system pathes.
+     * we must convert used system paths.
      * And java use another notation for file URLs ... correct it.
      *
      * @param aSystemPath
diff --git a/officecfg/registry/schema/org/openoffice/Office/Paths.xcs b/officecfg/registry/schema/org/openoffice/Office/Paths.xcs
index 90811bb..becdbd8 100644
--- a/officecfg/registry/schema/org/openoffice/Office/Paths.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/Paths.xcs
@@ -30,7 +30,7 @@
 
 	<info>
         <author>AS</author>
-		<desc>Configuration of layered pathes replacing the old path configuration org.openoffice.Office.Common/Path.</desc>
+		<desc>Configuration of layered paths replacing the old path configuration org.openoffice.Office.Common/Path.</desc>
 	</info>
 
 	<templates>
@@ -52,7 +52,7 @@
                 </info>
             <prop oor:name="IsSinglePath" oor:type="xs:boolean" oor:nillable="false">
 				<info>
-					<desc>Mark a NamedPath as SinglePath (false=MultiPath). Only the property WritePath is used for such single pathes then.</desc>
+					<desc>Mark a NamedPath as SinglePath (false=MultiPath). Only the property WritePath is used for such single paths then.</desc>
 				</info>
                 <value>false</value>
             </prop>
diff --git a/qadevOOo/runner/helper/URLHelper.java b/qadevOOo/runner/helper/URLHelper.java
index d003ab6..e84050d 100644
--- a/qadevOOo/runner/helper/URLHelper.java
+++ b/qadevOOo/runner/helper/URLHelper.java
@@ -43,7 +43,7 @@ import java.util.Enumeration;
 
 /**
  * It collects some static helper functons to handle URLs.
- * Sometimes it's neccessary to convert URL from/to system pathes.
+ * Sometimes it's neccessary to convert URL from/to system paths.
  * Or from string to strutural notations (e.g. com.sun.star.util.URL).
  * And sometimes java had another notation then the office it has.
  *
@@ -54,7 +54,7 @@ public class URLHelper
 
     /**
      * Because the office need URLs for loading/saving documents
-     * we must convert used system pathes.
+     * we must convert used system paths.
      * And java use another notation for file URLs ... correct it.
      *
      * @param aSystemPath
diff --git a/rsc/inc/rscrsc.hxx b/rsc/inc/rscrsc.hxx
index f949d2b..0251611 100644
--- a/rsc/inc/rscrsc.hxx
+++ b/rsc/inc/rscrsc.hxx
@@ -68,7 +68,7 @@ public:
         rtl::OString aLangName;         // language name
         rtl::OString aOutputRc;         // target file
         rtl::OString aLangSearchPath;   // language specific search path
-        ::std::list< rtl::OString >    aSysSearchDirs;    // pathes to search for images
+        ::std::list< rtl::OString >    aSysSearchDirs;    // paths to search for images
 
         OutputFile() {}
     };
diff --git a/setup_native/scripts/admin.pl b/setup_native/scripts/admin.pl
index 1aed821..5ddeabd 100644
--- a/setup_native/scripts/admin.pl
+++ b/setup_native/scripts/admin.pl
@@ -267,7 +267,7 @@ sub check_system_path
 }
 
 ##########################################################################
-# Searching a file in a list of pathes
+# Searching a file in a list of paths
 ##########################################################################
 
 sub get_sourcepath_from_filename_and_includepath
@@ -847,7 +847,7 @@ sub create_directory_structure
 
     foreach $dir (@startparents) { create_directory_tree($dir, \%fullpathhash, $targetdir, $dirhash); }
 
-    # Also adding the pathes of the startparents
+    # Also adding the paths of the startparents
     foreach $dir (@startparents)
     {
         if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }
diff --git a/solenv/bin/make_installer.pl b/solenv/bin/make_installer.pl
index 5bcee7f..4f35aed 100644
--- a/solenv/bin/make_installer.pl
+++ b/solenv/bin/make_installer.pl
@@ -316,7 +316,7 @@ if ( $installer::globals::globallogging ) { installer::files::save_file($logging
 
 ##############################################
 # Collecting all files from all include
-# pathes in global hashes.
+# paths in global hashes.
 ##############################################
 
 installer::worker::collect_all_files_from_includepathes($includepatharrayref);
@@ -889,7 +889,7 @@ for ( my $n = 0; $n <= $#installer::globals::languageproducts; $n++ )
     # There are two ways for a directory to be included into the epm directory list:
     # 1. Looking for all destination paths in the files array
     # 2. Looking for directories with CREATE flag in the directory array
-    # Advantage: Many pathes are hidden in zip files, they are not defined in the setup script.
+    # Advantage: Many paths are hidden in zip files, they are not defined in the setup script.
     # It will be possible, that in the setup script only those directoies have to be defined,
     # that have a CREATE flag. All other directories are created, if they contain at least one file.
 
diff --git a/solenv/bin/modules/installer/archivefiles.pm b/solenv/bin/modules/installer/archivefiles.pm
index af23ed2..21f8f2b 100644
--- a/solenv/bin/modules/installer/archivefiles.pm
+++ b/solenv/bin/modules/installer/archivefiles.pm
@@ -377,7 +377,7 @@ sub resolving_archive_flag
 
                         if ( $set_executable_privileges )
                         {
-                            # All pathes to executables are saved in the hash %executable_files_in_extensions
+                            # All paths to executables are saved in the hash %executable_files_in_extensions
                             my $compare_path = $newfile{'sourcepath'};
                             $compare_path =~ s/\\/\//g;  # contains only slashes for comparison reasons
                             if ( exists($executable_files_in_extensions{$compare_path}) )
diff --git a/solenv/bin/modules/installer/control.pm b/solenv/bin/modules/installer/control.pm
index 0b10320..54da21a 100644
--- a/solenv/bin/modules/installer/control.pm
+++ b/solenv/bin/modules/installer/control.pm
@@ -252,7 +252,7 @@ sub check_makecab_version
 }
 
 ######################################################################
-# Reading the environment variables for the pathes in ziplist.
+# Reading the environment variables for the paths in ziplist.
 # solarpath, solarenvpath, solarcommonpath, os, osdef, pmiscpath
 ######################################################################
 
diff --git a/solenv/bin/modules/installer/converter.pm b/solenv/bin/modules/installer/converter.pm
index 2fe728b..4b89244 100644
--- a/solenv/bin/modules/installer/converter.pm
+++ b/solenv/bin/modules/installer/converter.pm
@@ -166,7 +166,7 @@ sub copy_item_object
 }
 
 #################################################################
-# Windows pathes must not contain the following structure:
+# Windows paths must not contain the following structure:
 # c:\dirA\dirB\..\dirC
 # This has to be exchanged to
 # c:\dirA\dirC
diff --git a/solenv/bin/modules/installer/environment.pm b/solenv/bin/modules/installer/environment.pm
index c80d837..5459761 100644
--- a/solenv/bin/modules/installer/environment.pm
+++ b/solenv/bin/modules/installer/environment.pm
@@ -75,7 +75,7 @@ sub create_pathvariables
 }
 
 ##################################################
-# Replacing tilde in pathes, because of
+# Replacing tilde in paths, because of
 # problem with deep recursion (task 104830)
 ##################################################
 
diff --git a/solenv/bin/modules/installer/epmfile.pm b/solenv/bin/modules/installer/epmfile.pm
index 8d78f62..b7299ef 100644
--- a/solenv/bin/modules/installer/epmfile.pm
+++ b/solenv/bin/modules/installer/epmfile.pm
@@ -58,7 +58,7 @@ sub read_packagemap
     my $infoline = "\n\nCollected abbreviations and package names:\n";
     push(@installer::globals::logfileinfo, $infoline);
 
-    # Can be a comma separated list. All files have to be found in include pathes
+    # Can be a comma separated list. All files have to be found in include paths
     my $allpackagemapnames = installer::converter::convert_stringlist_into_hash(\$packagemapname, ",");
     foreach my $onepackagemapname ( keys %{$allpackagemapnames} )
     {
diff --git a/solenv/bin/modules/installer/packagelist.pm b/solenv/bin/modules/installer/packagelist.pm
index 1c5d6fa..d6b2f02 100644
--- a/solenv/bin/modules/installer/packagelist.pm
+++ b/solenv/bin/modules/installer/packagelist.pm
@@ -728,7 +728,7 @@ sub log_packages_content
 }
 
 #####################################################################
-# Creating assignments from modules to destination pathes.
+# Creating assignments from modules to destination paths.
 # This is required for logging in fileinfo file. Otherwise
 # the complete destination file would not be known in file list.
 # Saved in %installer::globals::moduledestination
@@ -754,7 +754,7 @@ sub create_module_destination_hash
 }
 
 #####################################################################
-# Adding the default pathes into the files collector for Unixes.
+# Adding the default paths into the files collector for Unixes.
 # This is necessary to know the complete destination path in
 # fileinfo log file.
 #####################################################################
diff --git a/solenv/bin/modules/installer/parameter.pm b/solenv/bin/modules/installer/parameter.pm
index 5f9638f..c5c7836 100644
--- a/solenv/bin/modules/installer/parameter.pm
+++ b/solenv/bin/modules/installer/parameter.pm
@@ -207,7 +207,7 @@ sub control_fundamental_parameter
 
 ##########################################################
 # The path parameters can be relative or absolute.
-# This function creates absolute pathes.
+# This function creates absolute paths.
 ##########################################################
 
 sub make_path_absolute
diff --git a/solenv/bin/modules/installer/scriptitems.pm b/solenv/bin/modules/installer/scriptitems.pm
index 905b37e..23e94d7 100644
--- a/solenv/bin/modules/installer/scriptitems.pm
+++ b/solenv/bin/modules/installer/scriptitems.pm
@@ -1046,7 +1046,7 @@ sub get_Destination_Directory_For_Item_From_Directorylist       # this is used f
 }
 
 ##########################################################################
-# Searching a file in a list of pathes
+# Searching a file in a list of paths
 ##########################################################################
 
 sub get_sourcepath_from_filename_and_includepath_classic
@@ -1214,7 +1214,7 @@ sub determine_directory_language_dependency
 }
 
 ##############################################################
-# Getting all source pathes for all files to be packed
+# Getting all source paths for all files to be packed
 # $item can be "Files" or "ScpActions"
 ##############################################################
 
@@ -2340,7 +2340,7 @@ sub resolve_links_with_flag_relative
     # Before this step is:
     # destination=program/libsalhelperC52.so.3, this will be the name of the link
     # destinationfile=program/libsalhelperC52.so.3, this will be the linked file or name
-    # If the flag RELATIVE is set, the pathes have to be analyzed. If the flag is not set
+    # If the flag RELATIVE is set, the paths have to be analyzed. If the flag is not set
     # (this will not occur in the future?) destinationfile has to be an absolute path name
 
     for ( my $i = 0; $i <= $#{$linksarrayref}; $i++ )
diff --git a/solenv/bin/modules/installer/windows/admin.pm b/solenv/bin/modules/installer/windows/admin.pm
index 6c79aae..194a65f 100644
--- a/solenv/bin/modules/installer/windows/admin.pm
+++ b/solenv/bin/modules/installer/windows/admin.pm
@@ -410,7 +410,7 @@ sub create_directory_structure
 
     foreach $dir (@startparents) { create_directory_tree($dir, \%fullpathhash, $targetdir, $dirhash); }
 
-    # Also adding the pathes of the startparents
+    # Also adding the paths of the startparents
     foreach $dir (@startparents)
     {
         if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }
diff --git a/solenv/bin/modules/installer/windows/directory.pm b/solenv/bin/modules/installer/windows/directory.pm
index 7a588ed..c72358d 100644
--- a/solenv/bin/modules/installer/windows/directory.pm
+++ b/solenv/bin/modules/installer/windows/directory.pm
@@ -175,7 +175,7 @@ sub create_unique_directorynames
 
         if ( ! $allvariables->{'NOSHORTDIRECTORYNAMES'} )
         {
-            # This process does not work for SDK, because of its long and similar pathes
+            # This process does not work for SDK, because of its long and similar paths
             $uniquename = make_short_dir_version($uniquename, $startlength, $hostname); # taking care of underlines!
         }
 
diff --git a/solenv/bin/modules/installer/windows/msp.pm b/solenv/bin/modules/installer/windows/msp.pm
index be9ed62..0de6eff 100644
--- a/solenv/bin/modules/installer/windows/msp.pm
+++ b/solenv/bin/modules/installer/windows/msp.pm
@@ -1402,7 +1402,7 @@ sub create_msp_patch
     if ( $installer::globals::languagepack ) { $pcpfilename =~ s/.pcp\s*$/languagepack.pcp/; }
     elsif ( $installer::globals::helppack ) { $pcpfilename =~ s/.pcp\s*$/helppack.pcp/; }
 
-    # Searching the pcp file in the include pathes
+    # Searching the pcp file in the include paths
     my $fullpcpfilenameref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$pcpfilename, $includepatharrayref, 1);
     if ( $$fullpcpfilenameref eq "" ) { installer::exiter::exit_program("ERROR: pcp file not found: $pcpfilename !", "create_msp_patch"); }
     my $fullpcpfilenamesource = $$fullpcpfilenameref;
diff --git a/solenv/bin/modules/installer/windows/update.pm b/solenv/bin/modules/installer/windows/update.pm
index 50d31f0..4378ecf 100644
--- a/solenv/bin/modules/installer/windows/update.pm
+++ b/solenv/bin/modules/installer/windows/update.pm
@@ -313,7 +313,7 @@ sub readdatabase
     if ( ! $allvariables->{'UPDATE_DATABASE_LISTNAME'} ) { installer::exiter::exit_program("ERROR: If \"UPDATE_DATABASE\" is set, \"UPDATE_DATABASE_LISTNAME\" is required.", "Main"); }
     my $listfilename = $allvariables->{'UPDATE_DATABASE_LISTNAME'};
 
-    # Searching the list in the include pathes
+    # Searching the list in the include paths
     my $listname = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$listfilename, $includepatharrayref, 1);
     if ( $$listname eq "" ) { installer::exiter::exit_program("ERROR: List file not found: $listfilename !", "readdatabase"); }
     my $completelistname = $$listname;
diff --git a/solenv/bin/modules/par2script/parameter.pm b/solenv/bin/modules/par2script/parameter.pm
index 9c8abec..38a2d39 100644
--- a/solenv/bin/modules/par2script/parameter.pm
+++ b/solenv/bin/modules/par2script/parameter.pm
@@ -51,7 +51,7 @@ sub usage
 --------------------------------------------------------------
 $par2script::globals::prog
 The following parameter are needed:
--i: include pathes, comma separated list
+-i: include paths, comma separated list
 -o: setup script file name
 -v: writing logfile.txt (optional)
 \@\@list: list of all par files
@@ -105,7 +105,7 @@ sub control_parameter
     if ($par2script::globals::includepathlist eq "")
     {
         print "\n************************************************\n";
-        print "Error: Include pathes not set not set (-i)!";
+        print "Error: Include paths not set not set (-i)!";
         print "\n************************************************\n";
         usage();
         exit(-1);
diff --git a/solenv/bin/modules/pre2par/parameter.pm b/solenv/bin/modules/pre2par/parameter.pm
index 763f196..a39dbd0 100644
--- a/solenv/bin/modules/pre2par/parameter.pm
+++ b/solenv/bin/modules/pre2par/parameter.pm
@@ -132,7 +132,7 @@ sub control_parameter
 
 ##########################################################
 # The path parameters can be relative or absolute.
-# This function creates absolute pathes.
+# This function creates absolute paths.
 ##########################################################
 
 sub make_path_absolute
diff --git a/solenv/bin/packimages.pl b/solenv/bin/packimages.pl
index 70823c5..12eb3ea 100755
--- a/solenv/bin/packimages.pl
+++ b/solenv/bin/packimages.pl
@@ -49,7 +49,7 @@ my $global_path;             # path to global images directory
 my $module_path;             # path to module images directory
 my $sort_file;               # path to file containing sorting data
 my @custom_path;             # path to custom images directory
-my @imagelist_path;          # pathes to directories containing the image lists
+my @imagelist_path;          # paths to directories containing the image lists
 my $verbose;                 # be verbose
 my $extra_verbose;           # be extra verbose
 my $do_rebuild = 0;          # is rebuilding zipfile required?
diff --git a/solenv/inc/settings.mk b/solenv/inc/settings.mk
index a8bd275..c3eddcd 100644
--- a/solenv/inc/settings.mk
+++ b/solenv/inc/settings.mk
@@ -1012,7 +1012,7 @@ JAVA*:=$(JAVAINTERPRETER)
 .EXPORT : JAVA JAVAI
 
 # Define SCPCOMP without wrapper because pre2par.pl chokes on DOS style
-# pathes. (See iz57443)
+# paths. (See iz57443)
 SCPCOMP=$(PERL) $(SOLARENV)/bin/pre2par.pl
 SCPLINK=$(PERL) $(SOLARENV)/bin/par2script.pl
 LZIP*=lzip
diff --git a/stoc/source/security/permissions.cxx b/stoc/source/security/permissions.cxx
index 93715e8..d832734 100644
--- a/stoc/source/security/permissions.cxx
+++ b/stoc/source/security/permissions.cxx
@@ -419,11 +419,11 @@ bool FilePermission::implies( Permission const & perm ) const SAL_THROW(())
 #ifdef SAL_W32
         return ((0 == ::rtl_ustr_compareIgnoreAsciiCase_WithLength(
                      demanded.m_url.pData->buffer, len, m_url.pData->buffer, len )) &&
-                (0 > demanded.m_url.indexOf( '/', len ))); // in addition, no deeper pathes
+                (0 > demanded.m_url.indexOf( '/', len ))); // in addition, no deeper paths
 #else
         return ((0 == ::rtl_ustr_reverseCompare_WithLength(
                      demanded.m_url.pData->buffer, len, m_url.pData->buffer, len )) &&
-                (0 > demanded.m_url.indexOf( '/', len ))); // in addition, no deeper pathes
+                (0 > demanded.m_url.indexOf( '/', len ))); // in addition, no deeper paths
 #endif
     }
     return false;
diff --git a/svtools/source/control/inettbc.cxx b/svtools/source/control/inettbc.cxx
index 94a65f2..668a65c 100644
--- a/svtools/source/control/inettbc.cxx
+++ b/svtools/source/control/inettbc.cxx
@@ -334,9 +334,9 @@ void SvtMatchContext_Impl::ReadFolder( const String& rURL,
                 || (aText.Len() > 1 && aText.Copy( aText.Len() - 2, 2 ).CompareToAscii( "/." ) == COMPARE_EQUAL)
                 || (aText.Len() > 2 && aText.Copy( aText.Len() - 3, 3 ).CompareToAscii( "/.." ) == COMPARE_EQUAL);
 
-    // for pure home pathes ( ~username ) the '.' at the end of rMatch
+    // for pure home paths ( ~username ) the '.' at the end of rMatch
     // means that it poits to root catalog
-    // this is done only for file contents since home pathes parsing is usefull only for them
+    // this is done only for file contents since home paths parsing is usefull only for them
     if ( bPureHomePath && rMatch.Equals( String::CreateFromAscii( "file:///." ) ) )
     {
         // a home that refers to /
diff --git a/tools/source/fsys/filecopy.cxx b/tools/source/fsys/filecopy.cxx
index 0aae52c..eddbcc8 100644
--- a/tools/source/fsys/filecopy.cxx
+++ b/tools/source/fsys/filecopy.cxx
@@ -321,7 +321,7 @@ FSysError FileCopier::ExecuteExact( FSysAction nActions, FSysExact eExact )
     DirEntry aAbsTarget = DirEntry( aTarget );
     pImp->nActions = nActions;
 
-    // check if both pathes are accessible and source and target are different
+    // check if both paths are accessible and source and target are different
     if ( !aAbsTarget.ToAbs() || !aAbsSource.ToAbs() || aAbsTarget == aAbsSource )
         return FSYS_ERR_ACCESSDENIED;
 
diff --git a/udkapi/com/sun/star/beans/XHierarchicalPropertySet.idl b/udkapi/com/sun/star/beans/XHierarchicalPropertySet.idl
index d8657d0..ca8c927 100644
--- a/udkapi/com/sun/star/beans/XHierarchicalPropertySet.idl
+++ b/udkapi/com/sun/star/beans/XHierarchicalPropertySet.idl
@@ -63,7 +63,7 @@ module com {  module sun {  module star {  module beans {
         used to access the elements of the hierarchy,
         are formed.  </p>
 
-    <p> Commonly a notation similar to filesystem pathes
+    <p> Commonly a notation similar to filesystem paths
         (separated by '/' slashes) or nested module names
         (separated by dots '.' or '::') is used.  </p>
 
diff --git a/unotools/inc/unotools/configitem.hxx b/unotools/inc/unotools/configitem.hxx
index 7910b68..fe6f437 100644
--- a/unotools/inc/unotools/configitem.hxx
+++ b/unotools/inc/unotools/configitem.hxx
@@ -63,7 +63,7 @@ namespace utl
     {
         CONFIG_NAME_PLAINTEXT_NAME, // unescaped local node name, for user display etc.
         CONFIG_NAME_LOCAL_NAME,     // local node name, for use in XNameAccess etc. ("Item", "Q & A")
-        CONFIG_NAME_LOCAL_PATH,     // one-level relative path, for use when building pathes etc.  ("Item", "Typ['Q &amp; A']")
+        CONFIG_NAME_LOCAL_PATH,     // one-level relative path, for use when building paths etc.  ("Item", "Typ['Q &amp; A']")
         CONFIG_NAME_FULL_PATH,       // full absolute path. ("/org.openoffice.Sample/Group/Item", "/org.openoffice.Sample/Set/Typ['Q &amp; A']")
 
         CONFIG_NAME_DEFAULT = CONFIG_NAME_LOCAL_PATH // default format
diff --git a/unotools/inc/unotools/configpathes.hxx b/unotools/inc/unotools/configpathes.hxx
index 30a0845..258ea01 100644
--- a/unotools/inc/unotools/configpathes.hxx
+++ b/unotools/inc/unotools/configpathes.hxx
@@ -95,7 +95,7 @@ namespace utl
 
         @param _sNestedPath
             A configuration path that maybe points to a descendant of the node
-            identified by <var>_sPrefixPath</var>, with both pathes starting
+            identified by <var>_sPrefixPath</var>, with both paths starting
             from the same node (or both being absolute).
 
         @param _sPrefixPath
@@ -108,7 +108,7 @@ namespace utl
         @returns
             <TRUE/>, if <var>_sPrefixPath</var> is  a prefix of <var>_sNestedPath</var>;
             <FALSE/> otherwise.<BR/>
-            If both pathes are equal <TRUE/> is returned.
+            If both paths are equal <TRUE/> is returned.
 
     */
     sal_Bool isPrefixOfConfigurationPath(::rtl::OUString const& _sNestedPath,
@@ -119,7 +119,7 @@ namespace utl
 
         @param _sNestedPath
             A configuration path that points to a descendant of the node
-            identified by <var>_sPrefixPath</var>, with both pathes starting
+            identified by <var>_sPrefixPath</var>, with both paths starting
             from the same node (or both being absolute).
 
         @param _sPrefixPath
diff --git a/unotools/inc/unotools/pathoptions.hxx b/unotools/inc/unotools/pathoptions.hxx
index 9029136..2ed1178 100644
--- a/unotools/inc/unotools/pathoptions.hxx
+++ b/unotools/inc/unotools/pathoptions.hxx
@@ -76,7 +76,7 @@ public:
     SvtPathOptions();
     virtual ~SvtPathOptions();
 
-    // get the pathes, not const because of using a mutex
+    // get the paths, not const because of using a mutex
     const String&   GetAddinPath() const;
     const String&   GetAutoCorrectPath() const;
     const String&   GetAutoTextPath() const;
@@ -102,7 +102,7 @@ public:
     const String&   GetUIConfigPath() const;
     const String&   GetFingerprintPath() const;
 
-    // set the pathes
+    // set the paths
     void            SetAddinPath( const String& rPath );
     void            SetAutoCorrectPath( const String& rPath );
     void            SetAutoTextPath( const String& rPath );
diff --git a/unotools/source/config/defaultoptions.cxx b/unotools/source/config/defaultoptions.cxx
index e37106f..cb68c88 100644
--- a/unotools/source/config/defaultoptions.cxx
+++ b/unotools/source/config/defaultoptions.cxx
@@ -248,7 +248,7 @@ SvtDefaultOptions_Impl::SvtDefaultOptions_Impl() : ConfigItem( ASCII_STR("Office
                 {
                     case ::com::sun::star::uno::TypeClass_STRING :
                     {
-                        // multi pathes
+                        // multi paths
                         if ( pValues[nProp] >>= aTempStr )
                             aFullPath = aPathOpt.SubstituteVariable( aTempStr );
                         else
@@ -260,7 +260,7 @@ SvtDefaultOptions_Impl::SvtDefaultOptions_Impl() : ConfigItem( ASCII_STR("Office
 
                     case ::com::sun::star::uno::TypeClass_SEQUENCE :
                     {
-                        // single pathes
+                        // single paths
                         aFullPath = OUString();
                         Sequence < OUString > aList;
                         if ( pValues[nProp] >>= aList )
diff --git a/unotools/source/config/moduleoptions.cxx b/unotools/source/config/moduleoptions.cxx
index c66bbff..aa2f076 100644
--- a/unotools/source/config/moduleoptions.cxx
+++ b/unotools/source/config/moduleoptions.cxx
@@ -144,7 +144,7 @@ struct FactoryInfo
 
         //---------------------------------------------------------------------------------------------------------
         // returns list of properties, which has changed only!
-        // We use given value of sNodeBase to build full qualified pathes ...
+        // We use given value of sNodeBase to build full qualified paths ...
         // Last sign of it must be "/". Beacuse we use it directly, without any additional things!
         css::uno::Sequence< css::beans::PropertyValue > getChangedProperties( const ::rtl::OUString& sNodeBase )
         {
@@ -926,7 +926,7 @@ sal_Bool SvtModuleOptions_Impl::ClassifyFactoryByName( const ::rtl::OUString& sN
 *//*-*************************************************************************************************************/
 void SvtModuleOptions_Impl::impl_Read( const css::uno::Sequence< ::rtl::OUString >& lFactories )
 {
-    // Expand every set node name in lFactories to full qualified pathes to his properties
+    // Expand every set node name in lFactories to full qualified paths to his properties
     // and get right values from configuration.
     const css::uno::Sequence< ::rtl::OUString > lProperties = impl_ExpandSetNames( lFactories  );
     const css::uno::Sequence< css::uno::Any >   lValues     = GetProperties( lProperties );
diff --git a/unotools/source/config/pathoptions.cxx b/unotools/source/config/pathoptions.cxx
index 65300ba..f743bf7 100644
--- a/unotools/source/config/pathoptions.cxx
+++ b/unotools/source/config/pathoptions.cxx
@@ -129,7 +129,7 @@ class SvtPathOptions_Impl
     public:
                         SvtPathOptions_Impl();
 
-        // get the pathes, not const because of using a mutex
+        // get the paths, not const because of using a mutex
         const String&   GetPath( SvtPathOptions::Pathes );
         const String&   GetAddinPath() { return GetPath( SvtPathOptions::PATH_ADDIN ); }
         const String&   GetAutoCorrectPath() { return GetPath( SvtPathOptions::PATH_AUTOCORRECT ); }
@@ -156,7 +156,7 @@ class SvtPathOptions_Impl
         const String&   GetUIConfigPath() { return GetPath( SvtPathOptions::PATH_UICONFIG ); }
         const String&   GetFingerprintPath() { return GetPath( SvtPathOptions::PATH_FINGERPRINT ); }
 
-        // set the pathes
+        // set the paths
         void            SetPath( SvtPathOptions::Pathes, const String& rNewPath );
         void            SetAddinPath( const String& rPath ) { SetPath( SvtPathOptions::PATH_ADDIN, rPath ); }
         void            SetAutoCorrectPath( const String& rPath ) { SetPath( SvtPathOptions::PATH_AUTOCORRECT, rPath ); }
diff --git a/wizards/com/sun/star/wizards/web/WWD_Startup.java b/wizards/com/sun/star/wizards/web/WWD_Startup.java
index e36051c..d81494d 100644
--- a/wizards/com/sun/star/wizards/web/WWD_Startup.java
+++ b/wizards/com/sun/star/wizards/web/WWD_Startup.java
@@ -476,7 +476,7 @@ public abstract class WWD_Startup extends WWD_General
 
             ConfigSet set = settings.cp_DefaultSession.cp_Publishing;
 
-            // now if path variables are used in publisher pathes, they
+            // now if path variables are used in publisher paths, they
             // are getting replaced here...
             for (int i = 0; i < set.getSize(); i++)
             {
diff --git a/wizards/com/sun/star/wizards/web/WWD_Startup.py b/wizards/com/sun/star/wizards/web/WWD_Startup.py
index 86d0091..b17a78f 100644
--- a/wizards/com/sun/star/wizards/web/WWD_Startup.py
+++ b/wizards/com/sun/star/wizards/web/WWD_Startup.py
@@ -255,7 +255,7 @@ class WWD_Startup(WWD_General):
             WWD_General.settings.readConfiguration(
                 confRoot, CONFIG_READ_PARAM)
             configSet = WWD_General.settings.cp_DefaultSession.cp_Publishing
-            # now if path variables are used in publisher pathes, they
+            # now if path variables are used in publisher paths, they
             # are getting replaced here...
             for i in xrange(configSet.getSize()):
                 p = configSet.getElementAt(i)


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index d94df43..9e26c30 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -304,7 +304,7 @@ PathSettings::PathInfo PathSettings::impl_readNewFormat(const ::rtl::OUString& s
         sal_Bool bFinalized = ((aInfo.Attributes & css::beans::PropertyAttribute::READONLY  ) == css::beans::PropertyAttribute::READONLY  );
 
         // Note: Till we support finalized / mandatory on our API more in detail we handle
         // all states simple as READONLY ! But because all realy needed pathes are "mandatory" by default
         // we have to handle "finalized" as the real "readonly" indicator .
         aPathVal.bIsReadonly = bFinalized;
     }
@@ -323,7 +323,7 @@ void PathSettings::impl_storePath(const PathSettings::PathInfo& aPath)
 
     // try to replace path-parts with well known and uspported variables.
     // So an office can be moved easialy to another location without loosing
-    // it's related pathes.
+    // it's related paths.
     PathInfo aResubstPath(aPath);
     impl_subst(aResubstPath, sal_True);
 
@@ -348,7 +348,7 @@ void PathSettings::impl_storePath(const PathSettings::PathInfo& aPath)
     // on loading time realy represent an user setting !!!
 
     // Check if the given path exists inside the old configuration.
     // Because our new configuration knows more then the list of old pathes ... !
     if (xCfgOld->hasByName(aResubstPath.sPathName))
     {
         css::uno::Reference< css::beans::XPropertySet > xProps(xCfgOld, css::uno::UNO_QUERY_THROW);
@@ -408,7 +408,7 @@ PathSettings::EChangeOp PathSettings::impl_updatePath(const ::rtl::OUString& sPa
         aPath = impl_readNewFormat(sPath);
         aPath.sPathName = sPath;
         // replace all might existing variables with real values
         // Do it before these old pathes will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
         impl_subst(aPath, sal_False);
@@ -427,7 +427,7 @@ PathSettings::EChangeOp PathSettings::impl_updatePath(const ::rtl::OUString& sPa
         // can be disabled for a new major
         OUStringList lOldVals = impl_readOldFormat(sPath);
         // replace all might existing variables with real values
         // Do it before these old pathes will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
         impl_subst(lOldVals, fa_getSubstitution(), sal_False);
@@ -893,7 +893,7 @@ void PathSettings::impl_setPathValue(      sal_Int32      nID ,
                     ::rtl::OUStringBuffer sMsg(256);
                     sMsg.appendAscii("The path '"    );
                     sMsg.append     (aChangePath.sPathName);
-                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal pathes cant be set.");
+                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal paths cant be set.");
                     throw css::uno::Exception(sMsg.makeStringAndClear(),
                                               static_cast< ::cppu::OWeakObject* >(this));
                 }
@@ -913,7 +913,7 @@ void PathSettings::impl_setPathValue(      sal_Int32      nID ,
                     ::rtl::OUStringBuffer sMsg(256);
                     sMsg.appendAscii("The path '"    );
                     sMsg.append     (aChangePath.sPathName);
-                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal pathes cant be set.");
+                    sMsg.appendAscii("' is defined as SINGLE_PATH. It's sub set of internal paths cant be set.");
                     throw css::uno::Exception(sMsg.makeStringAndClear(),
                                               static_cast< ::cppu::OWeakObject* >(this));
                 }
@@ -968,7 +968,7 @@ sal_Bool PathSettings::impl_isValidPath(const OUStringList& lPath) const
 sal_Bool PathSettings::impl_isValidPath(const ::rtl::OUString& sPath) const
 {
     // allow empty path to reset a path.
 // idea by LLA to support empty pathes
 //    if (sPath.getLength() == 0)
 //    {
 //        return sal_True;
@@ -304,7 +304,7 @@ PathSettings::PathInfo PathSettings::impl_readNewFormat(const ::rtl::OUString& s
 
         // Note: Till we support finalized / mandatory on our API more in detail we handle
-        // all states simple as READONLY ! But because all realy needed pathes are "mandatory" by default
+        // all states simple as READONLY ! But because all realy needed paths are "mandatory" by default
         // we have to handle "finalized" as the real "readonly" indicator .
         aPathVal.bIsReadonly = bFinalized;
@@ -348,7 +348,7 @@ void PathSettings::impl_storePath(const PathSettings::PathInfo& aPath)
 
     // Check if the given path exists inside the old configuration.
-    // Because our new configuration knows more then the list of old pathes ... !
+    // Because our new configuration knows more then the list of old paths ... !
     if (xCfgOld->hasByName(aResubstPath.sPathName))
     {
@@ -408,7 +408,7 @@ PathSettings::EChangeOp PathSettings::impl_updatePath(const ::rtl::OUString& sPa
         aPath.sPathName = sPath;
         // replace all might existing variables with real values
-        // Do it before these old pathes will be compared against the
+        // Do it before these old paths will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
@@ -427,7 +427,7 @@ PathSettings::EChangeOp PathSettings::impl_updatePath(const ::rtl::OUString& sPa
         OUStringList lOldVals = impl_readOldFormat(sPath);
         // replace all might existing variables with real values
-        // Do it before these old pathes will be compared against the
+        // Do it before these old paths will be compared against the
         // new path configuration. Otherwise some striungs uses different variables ... but substitution
         // will produce strings with same content (because some variables are redundant!)
@@ -968,7 +968,7 @@ sal_Bool PathSettings::impl_isValidPath(const OUStringList& lPath) const
 {
     // allow empty path to reset a path.
-// idea by LLA to support empty pathes
+// idea by LLA to support empty paths
 //    if (sPath.getLength() == 0)
 //    {
diff --git a/solenv/bin/modules/installer/downloadsigner.pm b/solenv/bin/modules/installer/downloadsigner.pm
index d3af898..575b42c 100644
--- a/solenv/bin/modules/installer/downloadsigner.pm
+++ b/solenv/bin/modules/installer/downloadsigner.pm
@@ -203,7 +203,7 @@ sub set_temp_path
 }
 
 #############################################
 # Setting output pathes to temp directory
 # This are the:
 # unpackpath and the loggingdir
 #############################################
@@ -217,7 +217,7 @@ sub set_output_pathes_to_temp
 }
 
 #############################################
 # Setting the minor into the pathes. This is
 # required, if the original installation set
 # was created without minor
 # Value is always saved in
@@ -241,15 +241,15 @@ sub set_minor_into_pathes
         return;
     }
 
-    # Affected pathes:
+    # Affected paths:
     # $contenthash{'installlogdir'}
     # $contenthash{'includepatharray'}
     # $installer::globals::unpackpath
     # $installer::globals::idttemplatepath
     # $installer::globals::idtlanguagepath
 
-    installer::logger::include_header_into_logfile("Changing saved pathes to add the minor");
-    my $infoline = "Old pathes:\n";
+    installer::logger::include_header_into_logfile("Changing saved paths to add the minor");
+    my $infoline = "Old paths:\n";
     push( @installer::globals::logfileinfo, $infoline);
     $infoline = "\$followmeinfohash->{'installlogdir'}: $followmeinfohash->{'installlogdir'}\n";
     push( @installer::globals::logfileinfo, $infoline);
@@ -259,7 +259,7 @@ sub set_minor_into_pathes
     push( @installer::globals::logfileinfo, $infoline);
     $infoline = "\$installer::globals::idtlanguagepath: $installer::globals::idtlanguagepath\n";
     push( @installer::globals::logfileinfo, $infoline);
-    $infoline = "Include pathes:\n";
+    $infoline = "Include paths:\n";
     push( @installer::globals::logfileinfo, $infoline);
     foreach my $path ( @{$followmeinfohash->{'includepatharray'}} ) { push( @installer::globals::logfileinfo, $path); }
 
@@ -304,7 +304,7 @@ sub set_minor_into_pathes
     if ( $installer::globals::idtlanguagepath =~ /\Q$srcpath\E/ ) { $installer::globals::idtlanguagepath =~ s/\Q$srcpath\E/$newsrcpath/; }
     foreach my $path ( @{$followmeinfohash->{'includepatharray'}} ) { if ( $path =~ /\Q$srcpath\E/ ) { $path =~ s/\Q$srcpath\E/$newsrcpath/; } }
 
-    $infoline = "\nNew pathes:\n";
+    $infoline = "\nNew paths:\n";
     push( @installer::globals::logfileinfo, $infoline);
     $infoline = "\$followmeinfohash->{'installlogdir'}: $followmeinfohash->{'installlogdir'}\n";
     push( @installer::globals::logfileinfo, $infoline);
@@ -314,7 +314,7 @@ sub set_minor_into_pathes
     push( @installer::globals::logfileinfo, $infoline);
     $infoline = "\$installer::globals::idtlanguagepath: $installer::globals::idtlanguagepath\n";
     push( @installer::globals::logfileinfo, $infoline);
-    $infoline = "Include pathes:\n";
+    $infoline = "Include paths:\n";
     push( @installer::globals::logfileinfo, $infoline);
     foreach my $path ( @{$followmeinfohash->{'includepatharray'}} ) { push( @installer::globals::logfileinfo, $path); }
 }
@@ -203,7 +203,7 @@ sub set_temp_path
 
 #############################################
-# Setting output pathes to temp directory
+# Setting output paths to temp directory
 # This are the:
 # unpackpath and the loggingdir
@@ -217,7 +217,7 @@ sub set_output_pathes_to_temp
 
 #############################################
-# Setting the minor into the pathes. This is
+# Setting the minor into the paths. This is
 # required, if the original installation set
 # was created without minor
diff --git a/solenv/bin/modules/installer/ziplist.pm b/solenv/bin/modules/installer/ziplist.pm
index c078155..3219e71 100644
--- a/solenv/bin/modules/installer/ziplist.pm
+++ b/solenv/bin/modules/installer/ziplist.pm
@@ -518,7 +518,7 @@ sub replace_packagetype_in_pathes
 }
 
 ####################################################
 # Removing ending separators in pathes
 ####################################################
 
 sub remove_ending_separator
@@ -546,7 +546,7 @@ sub replace_languages_in_pathes
 {
     my ( $patharrayref, $languagesref ) = @_;
 
-    installer::logger::include_header_into_logfile("Replacing languages in include pathes:");
+    installer::logger::include_header_into_logfile("Replacing languages in include paths:");
 
     my @patharray = ();
     my $infoline = "";
@@ -570,7 +570,7 @@ sub replace_languages_in_pathes
 
                 installer::remover::remove_leading_and_ending_whitespaces(\$newline);
 
                 # Is it necessary to refresh the global array, containing all files of all include pathes?
                 if ( -d $newdir )
                 {
                     # Checking if $newdir is empty
@@ -518,7 +518,7 @@ sub replace_packagetype_in_pathes
 
 ####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
 ####################################################
 
@@ -570,7 +570,7 @@ sub replace_languages_in_pathes
                 installer::remover::remove_leading_and_ending_whitespaces(\$newline);
 
-                # Is it necessary to refresh the global array, containing all files of all include pathes?
+                # Is it necessary to refresh the global array, containing all files of all include paths?
                 if ( -d $newdir )
                 {
diff --git a/solenv/bin/modules/par2script/work.pm b/solenv/bin/modules/par2script/work.pm
index c9b0bb1..10dd1ea 100644
--- a/solenv/bin/modules/par2script/work.pm
+++ b/solenv/bin/modules/par2script/work.pm
@@ -66,14 +66,14 @@ sub analyze_comma_separated_list
 }
 
 ############################################
 # setting list of include pathes
 ############################################
 
 sub setincludes
 {
     my ($list) = @_;
 
     # input is the comma separated list of include pathes
 
     my $includes = analyze_comma_separated_list($list);
 
@@ -131,7 +131,7 @@ sub make_complete_pathes_for_parfiles
 
         if ( ! $foundparfile )
         {
-            die "ERROR: Could not find parfile ${$parfiles}[$i] in includes pathes: $par2script::globals::includepathlist !\n";
+            die "ERROR: Could not find parfile ${$parfiles}[$i] in includes paths: $par2script::globals::includepathlist !\n";
         }
     }
 }
@@ -66,14 +66,14 @@ sub analyze_comma_separated_list
 
 ############################################
-# setting list of include pathes
+# setting list of include paths
 ############################################
 
@@ -66,14 +66,14 @@ sub analyze_comma_separated_list
     my ($list) = @_;
 
-    # input is the comma separated list of include pathes
+    # input is the comma separated list of include paths
 
     my $includes = analyze_comma_separated_list($list);
diff --git a/unotools/source/config/configitem.cxx b/unotools/source/config/configitem.cxx
index eb31e9c..615eb03 100644
--- a/unotools/source/config/configitem.cxx
+++ b/unotools/source/config/configitem.cxx
@@ -678,8 +678,8 @@ void lcl_normalizeLocalNames(Sequence< OUString >& _rNames, ConfigNameFormat _eF
                 break;
             }
         }
-        OSL_FAIL("Cannot create absolute pathes: missing interface");
-        // make local pathes instaed
+        OSL_FAIL("Cannot create absolute paths: missing interface");
+        // make local paths instaed
 
     case CONFIG_NAME_LOCAL_PATH:
         {
diff --git a/unotools/source/config/configpathes.cxx b/unotools/source/config/configpathes.cxx
index 6a583ba..8973e63 100644
--- a/unotools/source/config/configpathes.cxx
+++ b/unotools/source/config/configpathes.cxx
@@ -124,7 +124,7 @@ sal_Bool splitLastFromConfigurationPath(OUString const& _sInPath,
         {
             nPos =  _sInPath.lastIndexOf('/',nPos);
         }
-        else // defined behavior for invalid pathes
+        else // defined behavior for invalid paths
         {
             nStart = 0, nEnd = _sInPath.getLength();
             nPos = -1;
@@ -205,7 +205,7 @@ sal_Int32 lcl_findPrefixEnd(OUString const& _sNestedPath, OUString const& _sPref
     sal_Int32 nPrefixLength = _sPrefixPath.getLength();
 
     OSL_ENSURE(nPrefixLength == 0 || _sPrefixPath[nPrefixLength-1] != '/',
-                "Cannot handle slash-terminated prefix pathes");
+                "Cannot handle slash-terminated prefix paths");
 
     sal_Bool bIsPrefix;
     if (_sNestedPath.getLength() > nPrefixLength)